'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_INTEL_parallel_arrays'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_INTEL_parallel_arrays',error_checker=_errors._error_checker)
GL_COLOR_ARRAY_PARALLEL_POINTERS_INTEL=_C('GL_COLOR_ARRAY_PARALLEL_POINTERS_INTEL',0x83F7)
GL_NORMAL_ARRAY_PARALLEL_POINTERS_INTEL=_C('GL_NORMAL_ARRAY_PARALLEL_POINTERS_INTEL',0x83F6)
GL_PARALLEL_ARRAYS_INTEL=_C('GL_PARALLEL_ARRAYS_INTEL',0x83F4)
GL_TEXTURE_COORD_ARRAY_PARALLEL_POINTERS_INTEL=_C('GL_TEXTURE_COORD_ARRAY_PARALLEL_POINTERS_INTEL',0x83F8)
GL_VERTEX_ARRAY_PARALLEL_POINTERS_INTEL=_C('GL_VERTEX_ARRAY_PARALLEL_POINTERS_INTEL',0x83F5)
@_f
@_p.types(None,_cs.GLint,_cs.GLenum,arrays.GLvoidpArray)
def glColorPointervINTEL(size,type,pointer):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLvoidpArray)
def glNormalPointervINTEL(type,pointer):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLenum,arrays.GLvoidpArray)
def glTexCoordPointervINTEL(size,type,pointer):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLenum,arrays.GLvoidpArray)
def glVertexPointervINTEL(size,type,pointer):pass
