'''OpenGL extension INGR.interlace_read

This module customises the behaviour of the 
OpenGL.raw.GL.INGR.interlace_read to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a way to skip rows of pixels when reading
	or copying pixel rectangles.  This extension is complementary to
	the EXT_interlace extension except that it has no affect on getting
	texture images.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/INGR/interlace_read.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.INGR.interlace_read import *
from OpenGL.raw.GL.INGR.interlace_read import _EXTENSION_NAME

def glInitInterlaceReadINGR():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION