'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_debug_label'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_debug_label',error_checker=_errors._error_checker)
GL_BUFFER_OBJECT_EXT=_C('GL_BUFFER_OBJECT_EXT',0x9151)
GL_PROGRAM_OBJECT_EXT=_C('GL_PROGRAM_OBJECT_EXT',0x8B40)
GL_PROGRAM_PIPELINE_OBJECT_EXT=_C('GL_PROGRAM_PIPELINE_OBJECT_EXT',0x8A4F)
GL_QUERY_OBJECT_EXT=_C('GL_QUERY_OBJECT_EXT',0x9153)
GL_SAMPLER=_C('GL_SAMPLER',0x82E6)
GL_SHADER_OBJECT_EXT=_C('GL_SHADER_OBJECT_EXT',0x8B48)
GL_TRANSFORM_FEEDBACK=_C('GL_TRANSFORM_FEEDBACK',0x8E22)
GL_VERTEX_ARRAY_OBJECT_EXT=_C('GL_VERTEX_ARRAY_OBJECT_EXT',0x9154)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetObjectLabelEXT(type,object,bufSize,length,label):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLcharArray)
def glLabelObjectEXT(type,object,length,label):pass
