'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_VERSION_EGL_1_4'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_VERSION_EGL_1_4',error_checker=_errors._error_checker)
# EGL_DEFAULT_DISPLAY=_C('EGL_DEFAULT_DISPLAY',((EGLNativeDisplayType)0))
EGL_MULTISAMPLE_RESOLVE=_C('EGL_MULTISAMPLE_RESOLVE',0x3099)
EGL_MULTISAMPLE_RESOLVE_BOX=_C('EGL_MULTISAMPLE_RESOLVE_BOX',0x309B)
EGL_MULTISAMPLE_RESOLVE_BOX_BIT=_C('EGL_MULTISAMPLE_RESOLVE_BOX_BIT',0x0200)
EGL_MULTISAMPLE_RESOLVE_DEFAULT=_C('EGL_MULTISAMPLE_RESOLVE_DEFAULT',0x309A)
EGL_OPENGL_API=_C('EGL_OPENGL_API',0x30A2)
EGL_OPENGL_BIT=_C('EGL_OPENGL_BIT',0x0008)
EGL_SWAP_BEHAVIOR_PRESERVED_BIT=_C('EGL_SWAP_BEHAVIOR_PRESERVED_BIT',0x0400)
@_f
@_p.types(_cs.EGLContext,)
def eglGetCurrentContext():pass
