'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_pixel_transform'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_pixel_transform',error_checker=_errors._error_checker)
GL_AVERAGE_EXT=_C('GL_AVERAGE_EXT',0x8335)
GL_CUBIC_EXT=_C('GL_CUBIC_EXT',0x8334)
GL_MAX_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT=_C('GL_MAX_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT',0x8337)
GL_PIXEL_CUBIC_WEIGHT_EXT=_C('GL_PIXEL_CUBIC_WEIGHT_EXT',0x8333)
GL_PIXEL_MAG_FILTER_EXT=_C('GL_PIXEL_MAG_FILTER_EXT',0x8331)
GL_PIXEL_MIN_FILTER_EXT=_C('GL_PIXEL_MIN_FILTER_EXT',0x8332)
GL_PIXEL_TRANSFORM_2D_EXT=_C('GL_PIXEL_TRANSFORM_2D_EXT',0x8330)
GL_PIXEL_TRANSFORM_2D_MATRIX_EXT=_C('GL_PIXEL_TRANSFORM_2D_MATRIX_EXT',0x8338)
GL_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT=_C('GL_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT',0x8336)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetPixelTransformParameterfvEXT(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetPixelTransformParameterivEXT(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glPixelTransformParameterfEXT(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glPixelTransformParameterfvEXT(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glPixelTransformParameteriEXT(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glPixelTransformParameterivEXT(target,pname,params):pass
