'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGIX_clipmap'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGIX_clipmap',error_checker=_errors._error_checker)
GL_LINEAR_CLIPMAP_LINEAR_SGIX=_C('GL_LINEAR_CLIPMAP_LINEAR_SGIX',0x8170)
GL_LINEAR_CLIPMAP_NEAREST_SGIX=_C('GL_LINEAR_CLIPMAP_NEAREST_SGIX',0x844F)
GL_MAX_CLIPMAP_DEPTH_SGIX=_C('GL_MAX_CLIPMAP_DEPTH_SGIX',0x8177)
GL_MAX_CLIPMAP_VIRTUAL_DEPTH_SGIX=_C('GL_MAX_CLIPMAP_VIRTUAL_DEPTH_SGIX',0x8178)
GL_NEAREST_CLIPMAP_LINEAR_SGIX=_C('GL_NEAREST_CLIPMAP_LINEAR_SGIX',0x844E)
GL_NEAREST_CLIPMAP_NEAREST_SGIX=_C('GL_NEAREST_CLIPMAP_NEAREST_SGIX',0x844D)
GL_TEXTURE_CLIPMAP_CENTER_SGIX=_C('GL_TEXTURE_CLIPMAP_CENTER_SGIX',0x8171)
GL_TEXTURE_CLIPMAP_DEPTH_SGIX=_C('GL_TEXTURE_CLIPMAP_DEPTH_SGIX',0x8176)
GL_TEXTURE_CLIPMAP_FRAME_SGIX=_C('GL_TEXTURE_CLIPMAP_FRAME_SGIX',0x8172)
GL_TEXTURE_CLIPMAP_LOD_OFFSET_SGIX=_C('GL_TEXTURE_CLIPMAP_LOD_OFFSET_SGIX',0x8175)
GL_TEXTURE_CLIPMAP_OFFSET_SGIX=_C('GL_TEXTURE_CLIPMAP_OFFSET_SGIX',0x8173)
GL_TEXTURE_CLIPMAP_VIRTUAL_DEPTH_SGIX=_C('GL_TEXTURE_CLIPMAP_VIRTUAL_DEPTH_SGIX',0x8174)

