'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_OES_blend_func_separate'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_OES_blend_func_separate',error_checker=_errors._error_checker)
GL_BLEND_DST_ALPHA_OES=_C('GL_BLEND_DST_ALPHA_OES',0x80CA)
GL_BLEND_DST_RGB_OES=_C('GL_BLEND_DST_RGB_OES',0x80C8)
GL_BLEND_SRC_ALPHA_OES=_C('GL_BLEND_SRC_ALPHA_OES',0x80CB)
GL_BLEND_SRC_RGB_OES=_C('GL_BLEND_SRC_RGB_OES',0x80C9)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum)
def glBlendFuncSeparateOES(srcRGB,dstRGB,srcAlpha,dstAlpha):pass
