'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_NV_sRGB_formats'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_NV_sRGB_formats',error_checker=_errors._error_checker)
GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_NV=_C('GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_NV',0x8C4D)
GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_NV=_C('GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_NV',0x8C4E)
GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_NV=_C('GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_NV',0x8C4F)
GL_COMPRESSED_SRGB_S3TC_DXT1_NV=_C('GL_COMPRESSED_SRGB_S3TC_DXT1_NV',0x8C4C)
GL_ETC1_SRGB8_NV=_C('GL_ETC1_SRGB8_NV',0x88EE)
GL_SLUMINANCE8_ALPHA8_NV=_C('GL_SLUMINANCE8_ALPHA8_NV',0x8C45)
GL_SLUMINANCE8_NV=_C('GL_SLUMINANCE8_NV',0x8C47)
GL_SLUMINANCE_ALPHA_NV=_C('GL_SLUMINANCE_ALPHA_NV',0x8C44)
GL_SLUMINANCE_NV=_C('GL_SLUMINANCE_NV',0x8C46)
GL_SRGB8_NV=_C('GL_SRGB8_NV',0x8C41)

